/* glphbsm/free_hbsm.c */

/*----------------------------------------------------------------------
-- This file is a part of the GLPK package.
--
-- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
--                          Department for Applied Informatics,
--                          Moscow Aviation Institute, Moscow, Russia.
--                          All rights reserved.
--
-- This code is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This software is distributed "as is" in the hope that it will be
-- useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-- General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
----------------------------------------------------------------------*/

#include <stddef.h>
#include "glphbsm.h"
#include "glpset.h"

/*----------------------------------------------------------------------
-- free_hbsm - free sparse matrix in Harwell-Boeing format.
--
-- *Synopsis*
--
-- #include "glphbsm.h"
-- void free_hbsm(HBSM *hbsm);
--
-- *Description*
--
-- The free_hbsm routine frees all memory allocated to the object of
-- HBSM type that represents sparse matrix in Harwell-Boeing format. */

void free_hbsm(HBSM *hbsm)
{     if (hbsm->colptr != NULL) ufree(hbsm->colptr);
      if (hbsm->rowind != NULL) ufree(hbsm->rowind);
      if (hbsm->rhsptr != NULL) ufree(hbsm->rhsptr);
      if (hbsm->rhsind != NULL) ufree(hbsm->rhsind);
      if (hbsm->values != NULL) ufree(hbsm->values);
      if (hbsm->rhsval != NULL) ufree(hbsm->rhsval);
      if (hbsm->sguess != NULL) ufree(hbsm->sguess);
      if (hbsm->xexact != NULL) ufree(hbsm->xexact);
      ufree(hbsm);
      return;
}

/* eof */
